@@ -1,6 +1,6 @@
 /* backupfile.c -- make Emacs style backup file names
 
-   Copyright (C) 1990-2006, 2009-2022 Free Software Foundation, Inc.
+   Copyright (C) 1990-2006, 2009-2023 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@
 #include <dirent.h>
 #include <errno.h>
 #include <fcntl.h>
-#include <stdbool.h>
+#include <stdckdint.h>
 #include <stdint.h>
 #include <stdlib.h>
 #include <string.h>
@@ -34,7 +34,6 @@
 #include "attribute.h"
 #include "basename-lgpl.h"
 #include "ialloc.h"
-#include "intprops.h"
 #include "opendirat.h"
 #include "renameatu.h"
 
@@ -272,7 +271,7 @@ numbered_backup (int dir_fd, char **buffer, idx_t buffer_size, idx_t filelen,
       if (buffer_size < new_buffer_size)
         {
           idx_t grown;
-          if (! INT_ADD_WRAPV (new_buffer_size, new_buffer_size >> 1, &grown))
+          if (! ckd_add (&grown, new_buffer_size, new_buffer_size >> 1))
             new_buffer_size = grown;
           char *new_buf = irealloc (buf, new_buffer_size);
           if (!new_buf)
