@@ -1,32 +1,20 @@
-/*
- * buffer.c - read line by line with conversion of EOL types
- *
- * Copyright (c) 1988-1993 Miguel Santana
- * Copyright (c) 1995-1999 Akim Demaille, Miguel Santana
- */
+/* buffer.c - read line by line with conversion of EOL types
+   Copyright 1988-2017 Free Software Foundation, Inc.
 
-/*
- * This file is part of a2ps.
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 3, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; see the file COPYING.  If not, write to
- * the Free Software Foundation, 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
- */
+   This program is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 3, or (at your option)
+   any later version.
 
-/*
- * $Id: buffer.c,v 1.1.1.1.2.1 2007/12/29 01:58:34 mhatta Exp $
- */
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software
+   Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA
+   02110-1301, USA.  */
 
 /* FIXME: There is a case where the behavior is probably wrong: mixed
    string/stream buffers.  It may happen that the last char of the
@@ -36,12 +24,13 @@
 
    Currently it does not fetch that next char. */
 
+#include <config.h>
+
 #include "a2ps.h"
 #include "routines.h"
 #include "argmatch.h"
 #include "buffer.h"
-#include <assert.h>
-
+
 /****************************************************************/
 /*		 	Handling of the various eol styles	*/
 /****************************************************************/
@@ -100,17 +89,17 @@ enum eol_e
 option_string_to_eol (const char *option,
 		      const char *arg)
 {
-  ARGMATCH_ASSERT (eol_args, eol_types);
-  return XARGCASEMATCH (option, arg, eol_args, eol_types);
+  //ARGMATCH_VERIFY (eol_args, eol_types);
+  return XARGMATCH (option, arg, eol_args, eol_types);
 }
-
+
 /****************************************************************/
 /*		 	buffer_t Service routines 		*/
 /****************************************************************/
 static inline void
 buffer_internal_set (buffer_t * buffer,
 		     FILE * stream,
-		     const uchar * buf, size_t bufsize,
+		     const char * buf, size_t bufsize,
 		     bool pipe_p, enum eol_e eol)
 {
   buffer->buf = buf;
@@ -143,13 +132,13 @@ buffer_pipe_set (buffer_t * buffer, FILE * stream, enum eol_e eol)
 }
 
 void
-buffer_string_set (buffer_t * buffer, const uchar * string, enum eol_e eol)
+buffer_string_set (buffer_t * buffer, const char * string, enum eol_e eol)
 {
   buffer_internal_set (buffer, NULL, string, strlen (string), false, eol);
 }
 
 void
-buffer_buffer_set (buffer_t * buffer, const uchar * buf, size_t bufsize,
+buffer_buffer_set (buffer_t * buffer, const char * buf, size_t bufsize,
 		   enum eol_e eol)
 {
   buffer_internal_set (buffer, NULL, buf, bufsize, false, eol);
@@ -175,36 +164,23 @@ void
 buffer_self_print (buffer_t * buffer, FILE * stream)
 {
   if (buffer->buf)
-    fprintf (stream, "A string buffer.  Bufoffset %u\n",
+    fprintf (stream, "A string buffer.  Bufoffset %zu\n",
 	     buffer->bufoffset);
   if (buffer->stream)
     fprintf (stream, "A stream buffer (%s).\n",
 	     buffer->pipe_p ? "pipe" : "file");
-  fprintf (stream, "Len = %d, Lower case = %d, Line = %d\n",
+  fprintf (stream, "Len = %zu, Lower case = %d, Line = %zu\n",
 	   buffer->len, buffer->lower_case, buffer->line);
   if (buffer->len)
     fprintf (stream, "Content = `%s'\n", buffer->content);
 }
 
-/*
- * It frees the content, not the pointer
- */
-void
-buffer_release (buffer_t * buffer)
-{
-  /* VALUE is malloc'd only if BUFFER->LOWER_CASE */
-  if (buffer->lower_case)
-    free (buffer->value);
-  /* I don't know how this one should be used */
-  /*  obstack_free (&buffer->obstack, NULL); */
-}
-
 void
 buffer_set_lower_case (buffer_t * buffer, bool sensitive)
 {
   buffer->lower_case = sensitive;
 }
-
+
 /*
  * Get a line from BUFFER->STREAM.
  * Returns true  if a full line has been read,
@@ -214,7 +190,7 @@ buffer_set_lower_case (buffer_t * buffer, bool sensitive)
 static inline bool
 buffer_stream_get_line (buffer_t * buffer)
 {
-  register int c, d;
+  int c, d;
 
   while ((c = sgetc (buffer)) != EOF)
     switch (c)
@@ -248,7 +224,7 @@ buffer_stream_get_line (buffer_t * buffer)
 	    break;
 	  }
 	/* End it.  No need to NUL-terminate */
-	obstack_1grow (&buffer->obstack, c);
+	obstack_1grow (&buffer->obstack, (char) c);
 	return true;
 
       case '\r':
@@ -283,12 +259,12 @@ buffer_stream_get_line (buffer_t * buffer)
 	    break;
 	  }
 	/* End it.  No need to NUL-terminate */
-	obstack_1grow (&buffer->obstack, c);
+	obstack_1grow (&buffer->obstack, (char) c);
 	return true;
 
       default:
       stream_plain_char:
-	obstack_1grow (&buffer->obstack, c);
+	obstack_1grow (&buffer->obstack, (char) c);
 	break;
       }
 
@@ -296,7 +272,7 @@ buffer_stream_get_line (buffer_t * buffer)
      the last char was not an eol: report the line is not complete. */
   return false;
 }
-
+
 /*
  * Get a line from BUFFER->BUF
  *
@@ -311,7 +287,7 @@ buffer_stream_get_line (buffer_t * buffer)
 static inline bool
 buffer_string_get_line (buffer_t * buffer)
 {
-  register int c, d;
+  int c, d;
 
   while ((c = bgetc (buffer)) != EOF)
     switch (c)
@@ -345,7 +321,7 @@ buffer_string_get_line (buffer_t * buffer)
 	    break;
 	  }
 	/* End it.  No need to NUL-terminate */
-	obstack_1grow (&buffer->obstack, c);
+	obstack_1grow (&buffer->obstack, (char) c);
 	return true;
 
       case '\r':
@@ -380,12 +356,12 @@ buffer_string_get_line (buffer_t * buffer)
 	    break;
 	  }
 	/* End it.  No need to NUL-terminate */
-	obstack_1grow (&buffer->obstack, c);
+	obstack_1grow (&buffer->obstack, (char) c);
 	return true;
 
       default:
       string_plain_char:
-	obstack_1grow (&buffer->obstack, c);
+	obstack_1grow (&buffer->obstack, (char) c);
 	break;
       }
 
@@ -393,7 +369,7 @@ buffer_string_get_line (buffer_t * buffer)
      the last char was not an eol: report the line is not complete. */
   return false;
 }
-
+
 
 /* buffer_get
  *   if the language is case insensitive,
@@ -420,7 +396,10 @@ buffer_get (buffer_t * buffer)
      test on the length of the buffer. */
   buffer->len = obstack_object_size (&buffer->obstack);
   obstack_1grow (&buffer->obstack, '\0');
-  buffer->content = (uchar *) obstack_finish (&buffer->obstack);
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wsign-conversion"
+  buffer->content = obstack_finish (&buffer->obstack);
+#pragma GCC diagnostic pop
 
   /* One more line read */
   buffer->line++;
@@ -440,10 +419,10 @@ buffer_get (buffer_t * buffer)
 	buffer->allocsize = buffer->len + 1;
 
       buffer->value =
-	XREALLOC (buffer->value, uchar, buffer->allocsize);
+	xnrealloc (buffer->value, buffer->allocsize, sizeof(unsigned char));
 
       for (i = 0; i <= buffer->len; i++)
-	buffer->value[i] = tolower (buffer->content[i]);
+	buffer->value[i] = (char) tolower (buffer->content[i]);
     }
   else
     {
@@ -452,7 +431,7 @@ buffer_get (buffer_t * buffer)
 
   buffer->curr = 0;
 }
-
+
 /* buffer_sample_get
  *   extract a piece of a BUFFER's stream into FILENAME
  *
@@ -467,11 +446,11 @@ buffer_sample_get (buffer_t * buffer, const char *filename)
   FILE *out = xwfopen (filename);
   size_t cur = 0;
   int c;
-  char *sample_buffer = XMALLOC (char, SAMPLE_SIZE);
+  char *sample_buffer = XNMALLOC (SAMPLE_SIZE, char);
 
   for (; (cur < SAMPLE_SIZE) && ((c = sgetc (buffer)) != EOF); cur++)
     {
-      sample_buffer[cur] = c;
+      sample_buffer[cur] = (char) c;
       putc (c, out);
     }
 
