@@ -1,30 +1,22 @@
-/*
- * delegate.c
- *
- * Handling the delegations
- * Copyright (c) 1988, 89, 90, 91, 92, 93 Miguel Santana
- * Copyright (c) 1995, 96, 97, 98, 99 Akim Demaille, Miguel Santana
- *
- */
+/* delegate.c - handling the delegations
+   Copyright 1988-2017 Free Software Foundation, Inc.
 
-/*
- * This file is part of a2ps.
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; see the file COPYING.  If not, write to
- * the Free Software Foundation, 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
- */
+   This program is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 3, or (at your option)
+   any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software
+   Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA
+   02110-1301, USA.  */
+
+#include <config.h>
 
 #include "a2ps.h"
 #include "jobs.h"
@@ -82,19 +74,10 @@ delegate_name_len (struct delegation *delegation)
   return strlen (delegation->name);
 }
 
-static void
+static int
 delegate_name_fputs (struct delegation *delegation, FILE * stream)
 {
-  fputs (delegation->name, stream);
-}
-
-static void
-delegate_free (struct delegation *delegation)
-{
-  free (delegation->name);
-  free (delegation->contract);
-  free (delegation->command);
-  free (delegation);
+  return fputs (delegation->name, stream);
 }
 
 /*
@@ -103,22 +86,12 @@ delegate_free (struct delegation *delegation)
 struct hash_table_s *
 delegation_table_new (void)
 {
-  NEW (struct hash_table_s, res);
+  struct hash_table_s * res = XMALLOC (struct hash_table_s);
   hash_init (res, 8,
 	     delegate_hash_1, delegate_hash_2, delegate_hash_cmp);
   return res;
 }
 
-/*
- * Free the whole table
- */
-void
-delegation_table_free (struct hash_table_s *table)
-{
-  hash_free (table, (hash_map_func_t) delegate_free);
-  free (table);
-}
-
 /************************************************************************/
 /*              Use of the subcontracts                                 */
 /************************************************************************/
@@ -137,13 +110,13 @@ delegation_table_free (struct hash_table_s *table)
 		   _("missing argument for `%s'"), quotearg (contract_line));
 
 void
-add_delegation (const char *filename, int line,
+add_delegation (const char *filename, unsigned line,
 		char *contract_line)
 {
   char *cp, *cp2;
   struct delegation *contract;
 
-  contract = XMALLOC (struct delegation, 1);
+  contract = XMALLOC (struct delegation);
 
   /* Structure of the line:
      <name of contract> <source type>:<destination type> <command> */
@@ -155,7 +128,7 @@ add_delegation (const char *filename, int line,
   error_if_null (cp);
   cp2 = strtok (NULL, " \t\n");
   error_if_null (cp2);
-  contract->contract = XMALLOC (char, strlen (cp) + strlen (cp2) + 2);
+  contract->contract = XNMALLOC (strlen (cp) + strlen (cp2) + 2, char);
   sprintf (contract->contract, "%s:%s", cp, cp2);
 
   cp = strtok (NULL, "\n");
@@ -194,8 +167,8 @@ get_delegate_command (struct delegation *contract,
 {
   if (evaluate)
     return (char *) expand_user_string (job, file,
-					(const uchar *) "delegating command",
-					(const uchar *) contract->command);
+					"delegating command",
+					contract->command);
   else
     return contract->command;
 }
@@ -237,7 +210,7 @@ subcontract (struct file_job *fjob, buffer_t * buffer,
       /* We change the name of the file so that the correct file name
 	 is used in the command (that of the temporary file containing
 	 stdin). */
-      fjob->name = (uchar *) stdin_content_filename;
+      fjob->name = stdin_content_filename;
       command = get_delegate_command (contractor, fjob, 1);
       fjob->name = job->stdin_filename;
     }
@@ -370,7 +343,7 @@ subcontract (struct file_job *fjob, buffer_t * buffer,
   job->status->page_are_ordered = false;
   return true;
 }
-
+
 /************************************************************************/
 /*              "Visible" interface of the subcontracts                 */
 /************************************************************************/
@@ -389,7 +362,6 @@ dump_contract (FILE * stream, struct delegation *contract)
   fprintf (stream, _("Delegation `%s', from %s to %s\n"),
 	   contract->name, cp, cp2);
   fprintf (stream, "\t%s\n", contract->command);
-  free (cp);
 }
 
 /*
@@ -411,8 +383,6 @@ delegations_list_long (struct hash_table_s *contracts,
   for (i = 0; ordered_contracts[i]; i++)
     dump_contract (stream, ordered_contracts[i]);
   putc ('\n', stream);
-
-  free (ordered_contracts);
 }
 
 /*
@@ -434,5 +404,4 @@ delegations_list_short (struct hash_table_s *contracts,
                           (void *) ordered_contracts, (size_t) -1,
                           (lister_width_t) delegate_name_len,
                           (lister_print_t) delegate_name_fputs);
-  free (ordered_contracts);
 }
